==> meitorch-0.1.tar.gz: meitorch-0.1/setup.py <==
from distutils.core import setup
setup(
    name='meitorch',         # How you named your package folder (MyLib)
    packages=['meitorch'],   # Chose the same as "name"
    version='0.1',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Generate Most Exciting Input to explore and understand Tensorflow/PyTorch model's behavior "
                "by identifying input samples that induce high activation from specific neurons in your model.",   # Give a short description about your library
    author='László Freund',                   # Type in your name
    author_email='freundl0509@gmail.com',      # Type in your E-Mail
    url='https://github.com/lacykaltgr/mei',   # Provide either the link to your github or to your website
    download_url='https://github.com/lacykaltgr/mei/archive/refs/tags/v0.0.1.tar.gz',    # I explain this later on
    keywords=['generate', 'meitorch', 'most exciting', 'input optimization', 'interpretability'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
        'torch',
        'numpy',
        'scipy',
        'tqdm',
        'scikit-image',
        'torchvision',
        'matplotlib'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)

==> meitorch-0.222.tar.gz: meitorch-0.222/setup.py <==
from distutils.core import setup
from pathlib import Path
try:
    from pypandoc import convert_text
except ImportError:
    convert_text = lambda text, *args, **kwargs: text


setup(
    name='meitorch',         # How you named your package folder (MyLib)
    packages=['meitorch', 'meitorch/objective', 'meitorch/tools'],   # Chose the same as "name"
    version='0.222',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Generate Most Exciting Input to explore and understand PyTorch model's behavior "
                "by identifying input samples that induce high activation from specific neurons in your model.",   # Give a short description about your library
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='László Freund',                   # Type in your name
    author_email='freundl0509@gmail.com',      # Type in your E-Mail
    url='https://github.com/lacykaltgr/mei',   # Provide either the link to your github or to your website
    download_url='https://github.com/lacykaltgr/mei/archive/refs/tags/v0.0.1.tar.gz',    # I explain this later on
    keywords=['generate', 'meitorch', 'most exciting', 'input optimization', 'interpretability'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
        'torch',
        'numpy',
        'scipy',
        'tqdm',
        'scikit-image',
        'torchvision',
        'matplotlib'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
